from __future__ import unicode_literals

import click
import os

from . import config


@click.command('create-pypi')
@click.option('--username', nargs=1, default=config['PYPI_USERNAME'])
@click.option('--password', nargs=1, default=config['PYPI_PASSWORD'])
@click.option('--index', nargs=1, default=config['PYPI_INDEX'])
@click.option('--server', nargs=1, default=config['PYPI_SERVER'])
@click.option('--base-dir', nargs=1, default='~/')
@click.option('--dry', nargs=1, type=bool, default=False)
def create_pypi(username, password, index, server, base_dir, dry):
    root = os.path.expanduser(base_dir + '.pip')

    os.path.exists(root) or (dry or os.mkdir(root))

    files = [
        (
            os.path.join(os.path.expanduser(base_dir), '.pypirc'),
            [
                '[distutils]',
                'index-servers=',
                '\talt' if index else '\tpypi',
                '',
                '[alt]' if index else '[pypi]',
                'repository: {}'.format(server) if server else '',
                'username: {}'.format(username),
                'password: {}'.format(password)
            ]
        )
    ]
    if index:
        files += [
            (
                os.path.join(os.path.expanduser(base_dir), '.pydistutils.cfg'),
                [
                    '[easy_install]',
                    'index_url = https://{}:{}@{}'.format(
                        username, password, index
                    )
                ]
            ),
            (
                os.path.join(root, 'pip.conf'),
                [
                    '[global]',
                    'extra-index-url = https://{}:{}@{}'.format(
                        username, password, index
                    )
                ]
            )
        ]

    for file_path, contents in files:
        with open(file_path, 'w') as f:
            if dry:
                print ''
                print file_path
            for line in contents:
                if dry:
                    print line
                else:
                    f.write(line)
                    f.write('\n')
            if not dry:
                click.echo('wrote {}'.format(file_path))

    click.echo('created pypi setup files')



from __future__ import unicode_literals

import os as _os


__version__ = '0.2.5'


# TO use run:
# travis encrypt 'PYPI_PASSWORD=adsfasdfasdf' --add

config = dict(
    PYPI_USERNAME='omnibus',
    PYPI_PASSWORD=None,
    PYPI_INDEX='pypi.vandelay.io/balanced/prod/+simple/',
    PYPI_SERVER='https://pypi.vandelay.io/balanced/prod/',
    PUBLISH_BRANCH='master'
)


for k in config:
    config[k] = _os.environ.get(k, config[k])



#!/usr/bin/env python
"""
Jenkins' Cobertura plugin doesn't allow marking a build as successful or
failed based on coverage of individual packages -- only the project as a
whole. This script will parse the coverage.xml file and fail if the coverage of
specified packages doesn't meet the thresholds given
"""
from __future__ import unicode_literals
import logging
import logging.config
import sys

import click
from lxml import etree


logger = logging.getLogger(__name__)


PACKAGES_XPATH = etree.XPath('/coverage/packages/package')
FILES_XPATH = etree.XPath('/coverage/packages/package/classes/class')
PACKAGE_SEPARATOR = '.'


def check_package_coverage(root, package_coverage_dict):
    coverage_results = {}
    classes = FILES_XPATH(root)

    for cls in classes:
        class_path = cls.get('filename')
        class_coverage = float(cls.get('line-rate', '0.0')) * 100
        clses = class_path[:-3].split('/')
        for count in range(len(clses) + 1, 1, -1):
            target = '.'.join(clses[:count - 1])
            if target in package_coverage_dict:
                coverage_results.setdefault(target, [])
                coverage_results[target].append(class_coverage)
                break

    failed = False

    for package, coverages in coverage_results.iteritems():
        actual = sum(coverages) / len(coverages)
        required = package_coverage_dict[package]
        logger.info('Checking package {} -- needs {}% coverage'.format(
            package, required))
        if actual < required:
            logger.warning(
                'FAILED - Coverage for package {} is {}% -- minimum is '
                '{}%'.format(
                    package, actual, required
                )
            )
            failed = True
        else:
            logger.info('PASS {}% >= {}%'.format(actual, required))

    if set(package_coverage_dict.keys()) - set(coverage_results.keys()):
        failed = True
        not_found = ','.join(
            set(package_coverage_dict.keys()) - set(coverage_results.keys())
        )
        logger.warning(
            "FAILED - couldn't determine coverage for package(s) {}".format(
                not_found
            )
        )

    return failed


def run_coverage(filename, package_coverage_dict):
    xml = open(filename, 'r').read()
    root = etree.fromstring(xml)
    package_failed = False
    if package_coverage_dict:
        package_failed = check_package_coverage(root, package_coverage_dict)
    return package_failed


def handle_coverage(filename, packages):
    package_coverage_dict = {
        package: int(required_coverage) for
        package, required_coverage in (x.split(':') for x in packages if x)
    }

    return run_coverage(
        filename, package_coverage_dict
    )


@click.command()
@click.argument('filename')
@click.argument('packages', nargs=10)
def coverage(filename, packages):
    failed = handle_coverage(filename, packages)

    if failed:
        click.echo('Coverage test FAILED')
        sys.exit(1)

    click.echo('Coverage test SUCCEEDED')



from __future__ import unicode_literals

import os
from subprocess import call, check_output

import click

from . import config


@click.command('publish')
@click.option('--branch', nargs=1, default=config['PUBLISH_BRANCH'])
@click.option('--index', nargs=1, default=config['PYPI_INDEX'])
@click.option('--on-tag', is_flag=True)
def publish(branch, index, on_tag):
    if on_tag:
        tag = os.environ.get('TRAVIS_TAG')
        version = check_output('python setup.py --version', shell=True).strip()
        if not tag:
            click.echo('Not on tagged version, not releasing')
            return
        if tag != 'v{}'.format(version):
            click.echo('Tag "{}" != version "v{}"'.format(tag, version))
            return
    elif branch and branch != os.environ.get('TRAVIS_BRANCH', branch):
        click.echo('Not on the publishing branch')
        return
    args = ['python', 'setup.py', 'sdist', 'upload']
    if index:
        args += ['-r', 'alt']
    print ' '.join(args)
    return call(args)
